protocol

package
v0.0.0-...-a41ad85 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 31, 2021 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Marshal

func Marshal(message interface{ ProtoMessage() }) ([]byte, error)

Marshal marshals a message and handles any errors

func ToServerMessage

func ToServerMessage(m interface{ ProtoMessage() }) *pb.ServerMessage

ToServerMessage converts a message that is in the ServerMessage oneof to a ServerMessage object

func ToSpectatorUpdate

func ToSpectatorUpdate(msg interface{ ProtoMessage() }) *pb.SpectatorUpdate

ToSpectatorUpdate converts a message that is in the SpectatorUpdate oneof to a SpectatorUpdate object

func Unmarshal

func Unmarshal(data []byte) (result *pb.ClientMessage)

Unmarshal decodes a message. If invalid result will be nil

Types

This section is empty.

Jump to