Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ToServerMessage ¶
func ToServerMessage(m interface{ ProtoMessage() }) *pb.ServerMessage
ToServerMessage converts a message that is in the ServerMessage oneof to a ServerMessage object
func ToSpectatorUpdate ¶
func ToSpectatorUpdate(msg interface{ ProtoMessage() }) *pb.SpectatorUpdate
ToSpectatorUpdate converts a message that is in the SpectatorUpdate oneof to a SpectatorUpdate object
func Unmarshal ¶
func Unmarshal(data []byte) (result *pb.ClientMessage)
Unmarshal decodes a message. If invalid result will be nil
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.